/*
 * DFM_DRV_WIN.c
 *
 *  Created on: 2021年8月24日
 *      Author: happy
 */
#include "DFM_DRV.h"
#if defined(WIN32)
#include "cp_interface.h"
/**
* @brief 驱动初始化
* @return
ENUM_CM_TRUE 返回成功
ENUM_CM_TRUE 返回失败
*
*/
void DFM_drv_Init(void)
{

}

/**
* @brief 读取板卡id
* @return 板卡id
*
*/
CM_UINT8 getBoardID()
{
	CM_UINT8 boardId = 0;

	return boardId;
}
/*- 十路输入 */
CM_INT32 DFM_input(CM_UINT8 channel)
{

}
/*- 八路输出 */
CM_INT32 DFM_output(CM_UINT8 channel, CM_UINT8 level)
{

}
/**
* @brief run闪灯
*
*/
void DFM_ledRun(void)
{
    if(LED_run == 0)
    {
        LED_run = 2;
    }
    else
    {
        LED_run = 0;
    }
}

/**
* @brief error灯点亮
*
*/
void DFM_ledError(void)
{
    LED_err = 1;
}
void DFM_ledMS(CM_UINT8 light)
{
    if(light == 1)
    {
        LED_MS = 2;
    }
    else
    {
        LED_MS = light;
    }
}
/**
* @brief 检查网卡1到网卡4状态
*
*/
void DFM_ethernetState(void)
{

}

/**
* @brief 检查12V,24V,5V,3.3V,电压状态
*
*/
void DFM_voltageState()
{

}

/**
* @brief 获取板卡温度
*
*/
CM_FLOAT64 DFM_Get_Tmp112(void)
{
	return 25;
}
/**
* @brief 安全关断
*
*/
void DFM_saftyOff(void)
{
    /*- 停止反转gpio定时器+加个反馈打印 */
}

/**
* @brief 切系按钮
* return 1为按下
*/
CM_INT32 DFM_switchButton(void)
{

}
/**
* @brief 通道电流电压读取
* @param channel_1_shunt 核心3.3V电流 取值范围:-16~16
* @param channel_1_bus 核心3.3V电压 取值范围:0~26
* @param channel_2_shunt IO3.3V电流 取值范围:-16~16
* @param channel_2_bus IO3.3V电压 取值范围:0~26
* @param channel_3_shunt 核心5v电流 取值范围:-16~16
* @param channel_3_bus 核心5v电压 取值范围:0~26
* @return 返回结果 取值范围：0成功,-1失败
*/
CM_INT32 DFM_Read_ina3321(INOUT CM_INT32* channel_1_shunt, INOUT CM_FLOAT32* channel_1_bus, INOUT CM_INT32* channel_2_shunt, INOUT CM_FLOAT32* channel_2_bus, INOUT CM_INT32* channel_3_shunt, INOUT CM_FLOAT32* channel_3_bus)
{
    /*- 变量初始化 */
    CM_INT32 ret = -1;
    return ret;
}

CM_FLOAT64 DFM_Get_Tmp117(void)
{

}
/*- 从eeprom中读取信息 */
CM_INT32 DFM_Read_eeprom(IN CM_INT32 board, OUT CM_UINT8 rBuf[], IN CM_UINT32 len)
{

}
#endif
